/*
  Name:  ishi.sas
 Title:  Ethnicity, religiosity, and gender ideology
Source: Ishi-Kuntz, M. (1994) ``Ordinal log-linear models'', Sage, p.37
*/
options ls=80 ps=60 nocenter;
%include goptions;
goptions hsize=7in vsize=7in;
proc format ;
   value efmt 1='Hispanic'    2='White'    3='Black';
   value rfmt 1='Religious'   2='Moderate' 3='Non-rel.';
   value gfmt 1='Traditional' 2='Moderate' 3='Liberal';

data ishi ;
   input e  r  g  count @@;
   format e efmt. r rfmt. g gfmt.;

   label ethnicty = 'Ethnicity'
         relig    = 'Religiosity'
         gendidol = 'Gender ideology';
   ethnicty = put(e, efmt.);
   relig    = put(r, rfmt.);
   gendiol  = put(g, gfmt.);
cards;
3 1 1  58    3 1 2  45    3 1 3  49
3 2 1  11    3 2 2  17    3 2 3  21
3 3 1   3    3 3 2   4    3 3 3   7
1 1 1  83    1 1 2  24    1 1 3   8
1 2 1  16    1 2 2  17    1 2 3  13
1 3 1   7    1 3 2   6    1 3 3   2
2 1 1 317    2 1 2 242    2 1 3 145
2 2 1 105    2 2 2 157    2 2 3 148
2 3 1  41    2 3 2 109    2 3 3 150
;
/*
proc freq order=formatted ;
     weight count ;
     tables gendiol*(relig ethnicty) / noprint chisq measures cmh;
     tables relig*ethnicty / noprint chisq measures cmh;
     tables ethnicty*gendiol*relig / chisq measures cmh;
run ;
*/

%mosaic(data=ishi, var=Ethnicty Relig Gendiol,
	sort=g r descending ethnicty, plots=2 3, htext=1.7,
	title=%str(Gender Ideology, Religiosity and Ethnicity));