/*
   Name:   mospart.sas
   Title:  Mosaics plots for partial association


	The mospart module produces a series of mosaics plots for partial
	association, that is separate plots for each level of one or more
	by variables.

	Input parameters are the same as for mosaic, except that:
	
	byvar - specifies the variables (names or numbers) which are used to
		stratify the data.  One mosaic is produced for each combination
		of the levels of the byvars.  These may be composed into a single
		graphic using the %panels macro after the SAS/IML step.

	plots - is a global variable rather than an input parameter here.
		If not specified, plots = the number of variables not given as
		byvariables.

*/
start mospart(dim, table, vnames, lnames, title, byvar)
      global(config, devtype, fittype, filltype, shade, space, split, plots,
             htext, verbose, font, cellfill, vlabels, fuzz);
   factors = max(nrow(dim), ncol(dim));

	if type(byvar) = 'C'
		then byvar = name2num(row(byvar), row(vnames));
	if all(byvar=0) then do;
		print 'Error: BYVAR out of bounds in MOSPART';
		show vnames byvar; print byvar;
		return;
		end;
	others = remove( (1:factors), (byvar) );

	bydim = (shape(dim[byvar],1))`;
	byvn  = (shape(vnames[byvar],1))`;
	nby   = nrow(bydim);        *-- number of by variables;
	modim = dim[others];        *-- dimensions for each mosaic;
	rows  = modim[#];
	cols  = bydim[#];           *-- number of mosaic displays;
	* print byvar byvn bydim modim rows;
	cl = lnames[byvar,];
		
	if type(plots) ^= 'N'   then plots = ncol(others);
	if type(htext) ^= 'N'   then htext = cols;
	if type(vlabels) ^= 'N' then vlabels=0;
		
	* transpos table to put byvars first;
	order = shape(byvar,1)||others;
	dm = dim;
	vn = vnames;
	ln = lnames;
	tab = table;
	run transpos(dm, tab, vn, ln, order);
	* print dm vn ln tab;
	tab = shape(tab,rows);
	
	*-- construct labels for byvars;
	sep = ', ';
	do i=1 to nby;
      cur = ln[i,]`;
      if i=1 then cl=cur;
         else do;        /* construct row labels for prior factors */
            ol = repeat(cl, 1, dm[i]);
            ol = shape(ol,  dm[i]#nrow(cl), 1);
            nl = repeat( (cur[1:(dm[i])]), nrow(cl));
            cl = trim(rowcatc(ol || shape(sep,nrow(ol),1) ||nl));
         end;
		end;
	* print 'transposed, reshaped tab' tab[c=cl];
	print 'Mosaic plots for levels of' byvn, cl;
	
	pn = vn[1:nby];
	dm = dm[(nby+1):factors];
	vn = vn[(nby+1):factors];
	ln = ln[(nby+1):factors,];

   call gstart;
	do ip = 1 to cols;
		bylev = cl[ip];
		if nby=1
			then titl = trim(pn[1]) + ': ' + bylev;
			else titl = trim(cl[ip]);
		ptab = tab[,ip];
*		print 'Slab' ip byvn bylev vn ln; * ptab;
      run mosaic(dm, ptab, vn, ln, plots, titl);
	end;
	finish;


